@@ -1,7 +1,7 @@
 package Smart::Args::TypeTiny;
 use strict;
 use warnings;
-our $VERSION = "0.13";
+our $VERSION = "0.14";
 use Carp ();
 use PadWalker qw/var_name/;
 
@@ -319,12 +319,11 @@ For optimization calling subroutine in runtime type check, you can overwrite C<c
 
     {
         no warnings 'redefine';
-        sub Smart::Args::TypeTiny::check_rule {
-            my ($rule, $value, $exists, $name) = @_;
-            return $value;
-        }
+        *Smart::Args::TypeTiny::check_rule = \&Smart::Args::TypeTiny::Check::no_check_rule;
     }
 
+C<Smart::Args::TypeTiny::Check::no_check_rule> is a function without type checking and type coerce, but settings such as default and optional work the same as C<check_rule>.
+
 =head1 SEE ALSO
 
 L<Smart::Args>, L<Data::Validator>, L<Params::Validate>, L<Params::ValidationCompiler>
